Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index 2a248b7d9134f77e001bdac44d9a7887b6c33214..9476a589fe01075b340c0422d4dc5a8706499820 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -10448,12 +10448,12 @@ class JSArray: public JSObject { |
static const int kLengthOffset = JSObject::kHeaderSize; |
static const int kSize = kLengthOffset + kPointerSize; |
// 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
// we do not want to include in objects.h |
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with |
// kInitialMaxFastElementArray which is checked in a DCHECK in heap.cc. |
static const int kInitialMaxFastElementArray = |
- (600 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) / |
+ (300 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) / |
kPointerSize; |
private: |
@@ -10448,12 +10448,12 @@ class JSArray: public JSObject { |
static const int kLengthOffset = JSObject::kHeaderSize; |
static const int kSize = kLengthOffset + kPointerSize; |
- // 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
+ // 300 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
// we do not want to include in objects.h |
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with |